package controllers

import java.util.Date

import play.api._
import play.api.mvc._
import play.twirl.api.Html

class Application extends Controller {

  private val maxInactivityTime = 300000L // 5 minutes
  private val LAST_SEEN = "last_seen"
  private val MESSAGE = "message"

  def index = Action { implicit request =>
    val message = request.flash.get(MESSAGE).getOrElse("Welcome!")
    request.session.get(LAST_SEEN).map(s =>
      new Date().getTime - s.toLong > maxInactivityTime match {
        case true => renderFirstVisit(message)
        case false => renderAfterFirstVisit(message)
      }
    ).getOrElse(renderFirstVisit(message))
  }

  private def renderFirstVisit(message: String) = render(views.html.firstVisit(message))

  private def renderAfterFirstVisit(message: String) = render(views.html.afterFirstVisit(message))

  private def render(view: Html) = Ok(view) withSession(LAST_SEEN -> new Date().getTime.toString)

  def changeMessage(message: String) = Action { implicit request =>
    Redirect("/") flashing(MESSAGE -> message)
  }

}
